==> golang-github-containers-toolbox_0.0.99.2.orig.tar.xz: toolbox-0.0.99.2/src/cmd/help.go <==
/*
 * Copyright © 2019 – 2021 Red Hat Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cmd

import (
	"errors"
	"fmt"
	"os"

	"github.com/containers/toolbox/pkg/utils"
	"github.com/spf13/cobra"
)

var helpCmd = &cobra.Command{
	Use:   "help",
	Short: "Display help information about Toolbox",
	RunE:  help,
}

func init() {
	helpCmd.SetHelpFunc(helpHelp)
	rootCmd.AddCommand(helpCmd)
}

func help(cmd *cobra.Command, args []string) error {
	if utils.IsInsideContainer() {
		if !utils.IsInsideToolboxContainer() {
			return errors.New("this is not a toolbox container")
		}

		if _, err := utils.ForwardToHost(); err != nil {
			return err
		}

		return nil
	}

	if err := helpShowManual(args); err != nil {
		return err
	}

	return nil
}

func helpHelp(cmd *cobra.Command, args []string) {
	if utils.IsInsideContainer() {
		if !utils.IsInsideToolboxContainer() {
			fmt.Fprintf(os.Stderr, "Error: this is not a toolbox container\n")
			return
		}

		if _, err := utils.ForwardToHost(); err != nil {
			fmt.Fprintf(os.Stderr, "Error: %s\n", err)
			return
		}

		return
	}

	if err := helpShowManual(args); err != nil {
		fmt.Fprintf(os.Stderr, "Error: %s\n", err)
		return
	}
}

func helpShowManual(args []string) error {
	var manual string

	if len(args) == 0 {
		manual = "toolbox"
	} else if args[0] == executableBase {
		manual = "toolbox"
	} else {
		manual = "toolbox-" + args[0]
	}

	if err := utils.ShowManual(manual); err != nil {
		return err
	}

	return nil
}

==> golang-github-containers-toolbox_0.0.99.4.orig.tar.xz: toolbox-0.0.99.4/src/cmd/help.go <==
/*
 * Copyright © 2019 – 2022 Red Hat Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cmd

import (
	"errors"
	"fmt"
	"os"

	"github.com/containers/toolbox/pkg/utils"
	"github.com/spf13/cobra"
)

var helpCmd = &cobra.Command{
	Use:               "help",
	Short:             "Display help information about Toolbox",
	RunE:              help,
	ValidArgsFunction: completionCommands,
}

func init() {
	helpCmd.SetHelpFunc(helpHelp)
	rootCmd.AddCommand(helpCmd)
}

func help(cmd *cobra.Command, args []string) error {
	if utils.IsInsideContainer() {
		if !utils.IsInsideToolboxContainer() {
			return errors.New("this is not a toolbox container")
		}

		if _, err := utils.ForwardToHost(); err != nil {
			return err
		}

		return nil
	}

	if err := helpShowManual(args); err != nil {
		return err
	}

	return nil
}

func helpHelp(cmd *cobra.Command, args []string) {
	if utils.IsInsideContainer() {
		if !utils.IsInsideToolboxContainer() {
			fmt.Fprintf(os.Stderr, "Error: this is not a toolbox container\n")
			return
		}

		if _, err := utils.ForwardToHost(); err != nil {
			fmt.Fprintf(os.Stderr, "Error: %s\n", err)
			return
		}

		return
	}

	if err := helpShowManual(args); err != nil {
		fmt.Fprintf(os.Stderr, "Error: %s\n", err)
		return
	}
}

func helpShowManual(args []string) error {
	var manual string

	if len(args) == 0 {
		manual = "toolbox"
	} else if args[0] == executableBase {
		manual = "toolbox"
	} else {
		manual = "toolbox-" + args[0]
	}

	if err := showManual(manual); err != nil {
		return err
	}

	return nil
}
